@@ -371,7 +371,7 @@ fix_options = function(options) {
 #' # Test if current output format is 'docx'
 #' knitr::pandoc_to('docx')
 is_latex_output = function() {
-  out_format('latex') || pandoc_to(c('latex', 'beamer'))
+  out_format(c('latex', 'sweave', 'listings')) || pandoc_to(c('latex', 'beamer'))
 }
 
 #' @param fmt A character vector of output formats to be checked against. If not
@@ -383,6 +383,7 @@ is_latex_output = function() {
 #' @rdname output_type
 #' @export
 is_html_output = function(fmt = pandoc_to(), excludes = NULL) {
+  fmt = fmt %n% out_format()
   if (length(fmt) == 0) return(FALSE)
   if (grepl('^markdown', fmt)) fmt = 'markdown'
   if (fmt == 'epub3') fmt = 'epub'
@@ -490,24 +491,17 @@ fig_path = function(suffix = '', options = opts_current$get(), number) {
   if (missing(number)) number = options$fig.cur %n% 1L
   if (!is.null(number)) suffix = paste0('-', number, suffix)
   path = valid_path(options$fig.path, options$label)
-  (if (out_format(c('latex', 'sweave', 'listings'))) sanitize_fn else
-    paste0)(path, suffix)
+  if (getOption('knitr.sanitize.paths', out_format(c('latex', 'sweave', 'listings'))))
+    path = sanitize_fn(path)
+  paste0(path, suffix)
 }
 # sanitize filename for LaTeX
-sanitize_fn = function(path, suffix = '') {
-  if (grepl('[^~:_./\\[:alnum:]-]', path)) {
-    warning('replaced special characters in figure filename "', path, '" -> "',
-            path <- gsub('[^~:_./\\[:alnum:]-]', '_', path), '"')
-  }
-  # replace . with _ except ../ and ./
-  s = strsplit(path, '[/\\\\]')[[1L]]
-  i = (s != '.') & (s != '..') & grepl('\\.', s)
-  if (any(i)) {
-    s[i] = gsub('\\.', '_', s[i])
-    path = paste(s, collapse = '/')
-    warning('dots in figure paths replaced with _ ("', path, '")')
-  }
-  paste0(path, suffix)
+sanitize_fn = function(path, warn = TRUE) {
+  p = gsub('[^~:_./\\[:alnum:]-]', '_', path)
+  if (warn && (p != path)) warning(
+    "Replaced special characters in figure filename '", path, "' -> '", p, "'"
+  )
+  p
 }
 
 #' Obtain the figure filenames for a chunk
@@ -783,16 +777,38 @@ kpsewhich = function() {
 
 # check if a utility exists; if it does, save its availability in opts_knit
 has_utility = function(name, package = name) {
-  name2 = paste('util', name, sep = '_')  # e.g. util_pdfcrop
+  name2 = paste0('util_', name)  # e.g. util_pdfcrop
   if (is.logical(yes <- opts_knit$get(name2))) return(yes)
   # a special case: use tools::find_gs_cmd() to find ghostscript
-  if (name == 'ghostscript') name = tools::find_gs_cmd()
-  yes = nzchar(Sys.which(name))
-  if (!yes) warning(package, ' not installed or not in PATH')
+  if (name == 'pdfcrop') yes = has_crop_tools() else {
+    yes = nzchar(Sys.which(name))
+    if (!yes) warning(package, ' not installed or not in PATH')
+  }
   opts_knit$set(setNames(list(yes), name2))
   yes
 }
 
+# check if pdfcrop and ghostscript are available
+has_crop_tools = function(warn = TRUE) {
+  if (Sys.which('pdfcrop') == '') {
+    if (warn) warning("'pdfcrop' is required but not found")
+    return(FALSE)
+  }
+  if (is_windows() && Sys.which('tlmgr') != '') {
+    # assuming users know what this env var means (rstudio/tinytex#391)
+    if (Sys.getenv('TEXLIVE_WINDOWS_EXTERNAL_GS') != '') return(TRUE)
+    # TODO: use tinytex::tlmgr_version('list')$year
+    year = as.integer(xfun::grep_sub('^TeX Live.* version (\\d+).*$', '\\1', tinytex::tlmgr_version())[1])
+    if (year < 2023 && warn) warning(
+      'TeX Live version too low. Please consider upgrading, e.g., via tinytex::reinstall_tinytex().'
+    )
+    return(year >= 2023)
+  }
+  gs = tools::find_gs_cmd() != ''
+  if (warn && !gs) warning("'ghostscript' is required but not found")
+  gs
+}
+
 #' Query the current input filename
 #'
 #' Returns the name of the input file passed to \code{\link{knit}()}.
@@ -1099,7 +1115,16 @@ str_split = function(x, split, ...) {
 # default progress bar function in knitr: create a text progress bar, and return
 # methods to update/close it
 txt_pb = function(total, labels) {
-  s = ifelse(labels == '', '', sprintf(' (%s)', labels))  # chunk labels in ()
+  if (getOption('knitr.progress.linenums', FALSE)) {
+    nums = sapply(seq_along(labels), function(i) {
+      paste(current_lines(i), collapse = '-')
+    })
+    labels = sprintf(
+      '%s%s%s:%s', labels, ifelse(labels == '', '', ' @ '),
+      knit_concord$get('infile'), nums
+    )
+  }
+  s = ifelse(labels == '', '', sprintf(' [%s]', labels))  # chunk labels in []
   w = nchar(s)  # widths of labels
   n = max(w)
   # right-pad spaces for same width of all labels so a wider label of the
@@ -1107,17 +1132,32 @@ txt_pb = function(total, labels) {
   s = paste0(s, strrep(' ', n - w))
   w2 = getOption('width')
   con = getOption('knitr.progress.output', '')
+  cat_line = function(...) cat(..., sep = '', file = con)
+  # test if it is a "terminal" connection (whether \r is supported)
+  simple = (function() {
+    # a global option to decide whether to use the simple progress output
+    if (!is.null(res <- getOption('knitr.progress.simple'))) return(res)
+    if (identical(con, '')) con = stdout()
+    if (!inherits(con, 'connection')) return(TRUE)
+    if (isatty(con)) return(FALSE)
+    # when RStudio is available, return FALSE
+    is.null(tryCatch(rstudioapi::versionInfo(), error = function(e) NULL))
+  })()
+  # use simple progress output without the bar but only progress and labels
+  if (simple) return(list(
+    update = function(i) cat_line(i, '/', total, s[i], '\n')
+  ))
   pb = txtProgressBar(
     0, total, 0, '.', width = max(w2 - 10 - n, 10), style = 3, file = con
   )
   list(
     update = function(i) {
       setTxtProgressBar(pb, i)
-      cat(s[i], file = con)  # append chunk label to the progress bar
+      cat_line(s[i])  # append chunk label to the progress bar
     },
     done = function() {
       # wipe the progress bar
-      cat(paste0('\r', strrep(' ', max(w2, 10) + 10 + n)), file = con)
+      cat_line('\r', strrep(' ', max(w2, 10) + 10 + n))
       close(pb)
     }
   )
